==> haskell-prim-uniq-0.2-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-HsaEbEszLXmKROTFl6VWQO
key:                  prim-uniq-0.2-HsaEbEszLXmKROTFl6VWQO
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  cfb02ab3510e03fe2303a9e820c7feb7
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-HsaEbEszLXmKROTFl6VWQO
depends:
    base-4.17.2.1 dependent-sum-0.7.2.0-3prxvaoGdKECbeICL9GW97
    primitive-0.9.1.0-LKIwDdhUWCeBBmo7dhK3va

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prim-uniq-0.2-215-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-CDQH4YeWw0uJKcIkhVOgdB
key:                  prim-uniq-0.2-CDQH4YeWw0uJKcIkhVOgdB
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  e6e399446f55d8d82b81cd425ee4e75a
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-CDQH4YeWw0uJKcIkhVOgdB
depends:
    base-4.17.2.1 dependent-sum-0.7.2.0-KOPqRnFcokgJfkqZSg15kO
    primitive-0.9.1.0-8nzcMUtKW4yAfvV7oeRfvP

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
